html {
  height: 100%;
  width: 100%;
  background: rgb(73, 73, 73);
  background: radial-gradient(
    circle,
    rgba(73, 73, 73, 1) 8%,
    rgba(0, 0, 0, 1) 93%
  );
  font-family: "Advent Pro";
}

.box {
  height: 100vh;
  width: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  margin: auto;
  width: 50%;
  flex-direction: column;
  padding: 10px;
  color: #fff;
}

.logo {
  width: 200px;
}

a:link {
  color: #00ff00;
}

/* visited link */
a:visited {
  color: #00ff00;
}

/* mouse over link */
a:hover {
  color: #00ff00;
}

/* selected link */
a:active {
  color: #00ff00;
}
